@@ -6,21 +6,21 @@
 """
 import os
 import time
-import asyncmongo
 import tornado.gen as gen
 
 from threading import local
 from hashlib import sha1
 
-from gridfs import GridFS
-from redis import Redis, ConnectionPool
-from pymongo import Connection, MongoClient
 from tornado.web import RequestHandler
 from tornado.websocket import WebSocketHandler
 try:
+    from gridfs import GridFS
+    from redis import Redis, ConnectionPool
+    from pymongo import Connection, MongoClient
+    import asyncmongo
     import motor
-except:
-    print 'can not import motor '
+except Exception as e:
+    print e.message
 
 session_id = lambda: sha1('%s%s' % (os.urandom(16), time.time())).hexdigest()
 
@@ -39,15 +39,18 @@ class ContextHandler(object):
 
     def session(self, key, val=None):
         ''' session for handler '''
+        return get_context().session(self.get_redis_key(key), val)
+    
+    def clear_session(self, key):
+        get_context().clear_session(self.get_redis_key(key))
+    
+    def get_redis_key(self, key):
         _id = self.get_secure_cookie('session_id', None)
         if not _id:
             _id = session_id()
             self.set_secure_cookie('session_id', _id)
-        if __conf__.REDIS_SESSION:
-            return get_context().redis_session(_id, key, val)
-        else:
-            return get_context().session(_id, key, val)
-
+        return '{0}.{1}'.format(_id, key)
+        
 
 class LogicContext(object):
     """
@@ -61,7 +64,6 @@ class LogicContext(object):
         self._db_conn = None
         self._sync_db = None
         self._motor_clt = None
-        self._session = None
 
     def __enter__(self):
         if not hasattr(self._thread_local, "contexts"):
@@ -70,9 +72,6 @@ class LogicContext(object):
         return self
 
     def __exit__(self, exc_type, exc_value, trackback):
-        if self._session:
-            self._session.update(dict(
-                _id=self._session_id), {'$set': {'data': self._session_val}})
 
         self._thread_local.contexts.remove(self)
         if self._db_conn:
@@ -101,14 +100,7 @@ class LogicContext(object):
                                        network_timeout=__conf__.SOCK_TIMEOUT)
 
         return self._db_conn[name]
-    
 
-    def get_asyncmongo(self, name=None):
-        name = name or __conf__.DB_NAME
-        if not hasattr(self,'_async_db'):
-            self._async_db = asyncmongo.Client(pool_id='kpages_db', host=__conf__.DB_HOST, port=27017,dbname=name)
-
-        return self._async_db
 
     def get_async_mongo(self, name=None):
         """ get motor client"""
@@ -119,6 +111,13 @@ class LogicContext(object):
 
         return self._sync_db
 
+
+    def get_asyncmongo(self, dbname=None, **kwargs):
+        dbname = dbname or __conf__.DB_NAME
+        h, p = self._mongo_host.split(":") if ":" in self._mongo_host else (self._mongo_host, 27017)
+        db = asyncmongo.Client(pool_id='asyncmongo', host = h, port = int(p), dbname = dbname, **kwargs)
+        return db
+
     @gen.coroutine
     def get_motor(self, name=None):
         ''' yield  motor client '''
@@ -132,26 +131,16 @@ class LogicContext(object):
 
         raise gen.Return(self._motor_clt[name])
 
-    def session(self, _id, key, val=None, expire=None):
-        ''' mongodb session for tornado'''
-        if not self._session:
-            self._session = self.get_mongoclient('session')['session']
-            self._session_val = (
-                self._session.find_one(dict(_id=_id)) or {}).get('data', {})
-            self._session_id = _id
 
-        if not val:
-            return self._session_val.get(key)
-        if not self._session_val:
-            self._session.insert(dict(_id = _id, data = dict(key = val)))
-
-        self._session_val[key] = val
-
-    def redis_session(self, _id, key, val=None):
+    def session(self, key, val=None, expire= None):
         '''
         redis session for tornado
         '''
-        return self.get_redis().hset(_id, key, val) if val else self.get_redis().hget(_id, key)
+        expire = expire or __conf__.SESSION_EXPIRE
+        return self.get_redis().setex(key, val, expire) if val else self.get_redis().get(key)
+    
+    def clear_session(self, key):
+        self.get_redis().delete(key)
 
     @classmethod
     def get_context(cls):
