@@ -11,14 +11,15 @@
 # 服务器监听端口
 PORT = 8088
 
+# http accept ip 
+BIND_IP = None
+
 # 数据库超时时间
 SOCK_TIMEOUT = 10
+SOCK_TIMEOUT_MS = None
 
 # SESSION 过期时间(秒)
-SESSION_EXPIRE = 60 * 10
-
-#是否使用redis ression
-REDIS_SESSION = False
+SESSION_EXPIRE = 30*24*60*60
 
 # 是否启动调试模式
 DEBUG = True
@@ -47,6 +48,9 @@ COOKIE_SECRET = "61oETzKXQAGaYdkL5gEmGeJJFuYh7EQnp2XdTP1o/Vo="
 # COOKIE 安全
 XSRF_COOKIES = False
 
+# 数据库与缓存是否使用持久连接
+PERSISTENT_DB_CONNECTION = False
+
 # 缓存服务器
 CACHE_HOST = "localhost"
 
@@ -59,3 +63,5 @@ DB_NAME = "test"
 GFS_NAME = 'gfs'
 
 SERVICE_CHANNEL = "channel1"
+
+SERVICE_LISTKEY = "kpages_cmd_list"
